#
# spec file for package python-databases
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-databases
Version:        0.9.0
Release:        1.2
Summary:        Async database support for Python
License:        BSD-3-Clause
URL:            https://github.com/encode/databases
Source:         https://github.com/encode/databases/archive/%{version}.tar.gz#/databases-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-sqlalchemy >= 2.0.7
Suggests:       python-aiomysql
Suggests:       python-aiopg
Suggests:       python-aiosqlite
Suggests:       python-asyncpg
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module aiosqlite}
BuildRequires:  %{python_module asyncpg}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module sqlalchemy >= 2.0.7}
# /SECTION
%python_subpackages

%description
Async database support for Python.

%prep
%autosetup -p1 -n databases-%{version}

# tests/test_integration.py depends on starlette
rm tests/test_integration.py

# Remove test dependencies aiopg, aiomysql and asyncmy
sed -Ei 's/from .*(aiopg|mysql|asyncmy).* import .*/pass/' tests/test_connection_options.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export TEST_DATABASE_URLS=sqlite:///mytestdb
export PYTHONPATH=${PWD}
%pytest -k 'not (aiopg or mysql or asyncmy)'

%files %{python_files}
%doc README.md
%license LICENSE.md
%{python_sitelib}/databases
%{python_sitelib}/databases-%{version}.dist-info

%changelog
* Tue Sep 17 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.9.0:
  * Added
    + Allow SQLite query parameters and support cached databases
    + Support for unix socket for aiomysql and asyncmy
  * Changed
    + Drop support for Python 3.7 and add support for Python 3.12
    + Add support for SQLAlchemy 2+
    + Allow SSL string parameters in PostgresSQL URL
    + Change isolation connections and transactions during concurrent usage
    + Bump up asyncmy version to fix No module named 'asyncmy.connection'
  * Fixed
    + Fix the type-hints using more standard mode
- Switch to pyproject macros.
* Tue Jul  4 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Tue Jun  6 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.7.0:
  * Fixed breaking changes in SQLAlchemy cursor; supports >=1.4.42,<1.5
  * Wrapped types in typing.Optional where applicable
- Change {Build,}Requires for SQLAlchemy so we don't install >= 2.
- Drop patch sqlalchemy1442.patch, included upstream.
* Thu Nov 24 2022 Daniel Garcia <daniel.garcia@suse.com>
- Add patch sqlalchemy1442.patch to make it compatible with latest sqlalchemy
  gh#encode/databases#513
- Remove python_module macro definition
- Update to 0.6.2:
  * Pinned SQLAlchemy <=1.4.41 to avoid breaking changes (#520).
- 0.6.1:
  * Improve typing for Transaction (#493)
  * Allow string indexing into Record (#501)
- 0.6.0:
  * Dropped Python 3.6 support (#458)
  * Add _mapping property to the result set interface (#447 )
  * Add contributing docs (#453 )
  * Fix query result named access (#448)
  * Fix connections getting into a bad state when a task is cancelled (#457)
  * Revert #328 parallel transactions (#472)
  * Change extra installations to specific drivers (#436)
- 0.5.5:
  * Revert the change of Record type to Sequence from Mapping(#408) to maintain
    backward compatibility
- 0.5.4:
  * Support for Unix domain in connections (#423)
  * asyncmy MySQL driver (#382)
  * Fix SQLite fetch queries with multiple parameters (#435)
  * Change Record type to Sequence (#408)
* Sun Oct 17 2021 Ben Greiner <code@bnavigator.de>
- Update to version 0.5.3
  * Support dialect+driver for default database drivers like
    postgresql+asyncpg (#396)
  * Documentation of low-level transaction (#390)
- Release 0.5.2
  * Reset counter for failed connections (#385)
  * Avoid dangling task-local connections after
    Database.disconnect() (#211)
- Release 0.5.1
  * Make database connect and disconnect calls idempotent (#379)
  * Fix in_ and notin_ queries in SQLAlchemy 1.4 (#378)
- Release 0.5.0 (August 26th, 2021)
  * Support SQLAlchemy 1.4 (#299)
  * Fix concurrent transactions (#328)
- Drop sqlalchemy-14.patch fixed upstream
* Wed May 26 2021 Matej Cepl <mcepl@suse.com>
- Add sqlalchemy-14.patch upgrading used API of SQLAlchemy to 1.4.
* Tue Apr 13 2021 simmphonie@opensuse.org
- update to version 0.4.3
  * Pin SQLAlchemy to < 1.4 (#314)
- version 0.4.2
  * Fix memory leak with asyncpg for SQLAlchemy generic functions (#273)
- fix python version to "< 3.7" for aiocontextvars
* Sat Jan 16 2021 Benjamin Greiner <code@bnavigator.de>
- Requires aiocontextvars for python <= 3.6
* Sat Nov 21 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.4.1
